# TODO

1. Quick create is too ambiguous
1. Canvas should check fv and op before manipulating
1. quick create should have options to specify field_value
1. should be able to remove operations and wires (from Aquarium plan online)
1. should check for redundant wires
1. should not be able to wire a part to a non-part
1. quick wire should only wire to field_values that are empty??? so you can quick wire an array?
1. quick wiring arrays should keep adding field_values
1. maybe call quick_wire a quick_fill?
1. Designer, test remove_wire
1. Designer, test optimize plan
1. Designer, test setting field values from wiring..
1. Designer, determine 'orange' vs 'green' for wires and field_values

1. make plan creation easier
1. add image of plans to examples in Trident
1. plan validation before submission (route from Aquarium?)
1. document creating samples with properties
1. document making associations, getting associations, associating
files, downloading files